use crate::innerlude::*;

pure_props! {
    /// Bulma [Block](https://bulma.io/documentation/elements/block/) Element
    pub struct Block {}
}

pure_wrapper!(Block: <div class="block"/>);
